﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using ClientServer.Db;
using ClientServer.Models.Exercises.Tests;

namespace ClientServer.Models.CustomProjects
{
    /// <summary>
    /// results are stored in CustomProjectTestWithSolutionAsTestResult.cs so that we can have one test for
    /// multiple languages (and every lang can store it's own test result)
    /// </summary>
    public class CustomProjectTest
    {
        public CustomProjectTest()
        {
            TestAssets = new List<CustomProjectTestAsset>();
            AssetReferences = new List<CustomProjectTestWithFileAsAssetReference>();
        }
        
        public int Id { get; set; }
        /// <summary>
        /// the name
        /// </summary>
        [MaxLength(YapexDbContext.DefaultMaxStringLength)]
        public string DisplayName { get; set; }
        /// <summary>
        /// the content for the ... see the black-box-test protocol
        /// </summary>
        [MaxLength(YapexDbContext.TestContentMaxStringLength)]
        public string Content { get; set; }
        
        /// <summary>
        /// the index for the frontend sorting (>= 0, 0 is first, 1 second, ...)
        /// </summary>
        public int DisplayIndex { get; set; }

        /// <summary>
        /// the weight of the test (points)
        /// and to make it compatible with normal tests
        /// </summary>
        public int Weight { get; set; }
        
        public int TestTypeId { get; set; }
        /// <summary>
        /// the connected <see cref="TestType"/>
        /// </summary>
        public TestType TestType { get; set; }
        
        /// <summary>
        /// all related test assets for this e.g. a file to read
        /// </summary>
        public List<CustomProjectTestAsset> TestAssets { get; set; }
        
        /// <summary>
        /// all related test assets for this e.g. a file to read
        /// </summary>
        public List<CustomProjectTestWithFileAsAssetReference> AssetReferences { get; set; }


        public int TestSettingsId { get; set; }
        public TestSettings TestSettings { get; set; }
        
        
        public int CustomProjectId { get; set; }
        /// <summary>
        /// the connected <see cref="CustomProject"/>
        /// </summary>
        public CustomProject CustomProject { get; set; }
        
        public List<CustomProjectTestWithSolutionAsTestResult> TestResults { get; set; }

    }
}
